==> folly_fields-0.22.3.tar.gz: lib/validators/time_validator.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:folly_fields/util/folly_utils.dart';
import 'package:folly_fields/util/mask_text_input_formatter.dart';
import 'package:folly_fields/validators/abstract_validator.dart';

///
///
///
class TimeValidator extends AbstractParserValidator<TimeOfDay> {
  ///
  ///
  ///
  TimeValidator()
      : super(
          <TextInputFormatter>[
            MaskTextInputFormatter(
              mask: 'AB:CB',
              filter: <String, RegExp>{
                'A': RegExp('[0-2]'),
                'B': RegExp('[0-9]'),
                'C': RegExp('[0-5]'),
              },
            ),
          ],
        );

  ///
  ///
  ///
  @override
  String format(TimeOfDay value) => '${value.hour.toString().padLeft(2, '0')}'
      ':${value.minute.toString().padLeft(2, '0')}';

  ///
  ///
  ///
  @override
  String strip(String value) => value;

  ///
  ///
  ///
  @override
  bool isValid(String value) => valid(value) == null;

  ///
  ///
  ///
  @override
  TextInputType get keyboard => TextInputType.datetime;

  ///
  ///
  ///
  @override
  TimeOfDay? parse(String? value) {
    if (value != null && isValid(value)) {
      List<String> parts = value.split(':');
      if (parts.length == 2) {
        return TimeOfDay(
          hour: int.parse(parts.first),
          minute: int.parse(parts.last),
        );
      }
    }

    return null;
  }

  ///
  ///
  ///
  @override
  String? valid(String value) => FollyUtils.validTime(value);

  ///
  ///
  ///
  String formatDateTime(DateTime dateTime) =>
      format(TimeOfDay.fromDateTime(dateTime));
}

==> folly_fields-1.2.1.tar.gz: lib/validators/time_validator.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:folly_fields/util/folly_utils.dart';
import 'package:folly_fields/util/mask_text_input_formatter.dart';
import 'package:folly_fields/validators/abstract_validator.dart';

///
///
///
class TimeValidator extends AbstractParserValidator<TimeOfDay> {
  ///
  ///
  ///
  TimeValidator()
      : super(
          <TextInputFormatter>[
            MaskTextInputFormatter(
              mask: 'AB:CB',
              filter: <String, RegExp>{
                'A': RegExp('[0-2]'),
                'B': RegExp('[0-9]'),
                'C': RegExp('[0-5]'),
              },
            ),
          ],
        );

  ///
  ///
  ///
  @override
  String format(TimeOfDay value) => '${value.hour.toString().padLeft(2, '0')}'
      ':${value.minute.toString().padLeft(2, '0')}';

  ///
  ///
  ///
  @override
  String strip(String value) => value;

  ///
  ///
  ///
  @override
  bool isValid(String value) => valid(value) == null;

  ///
  ///
  ///
  @override
  TextInputType get keyboard => TextInputType.datetime;

  ///
  ///
  ///
  @override
  TimeOfDay? parse(String? value) {
    if (value != null && isValid(value)) {
      final List<String> parts = value.split(':');
      if (parts.length == 2) {
        return TimeOfDay(
          hour: int.parse(parts.first),
          minute: int.parse(parts.last),
        );
      }
    }

    return null;
  }

  ///
  ///
  ///
  @override
  String? valid(String value) => FollyUtils.validTime(value);

  ///
  ///
  ///
  String formatDateTime(DateTime dateTime) =>
      format(TimeOfDay.fromDateTime(dateTime));
}
